summaryrefslogtreecommitdiffhomepage
path: root/pkg/syserr/host_linux.go
diff options
context:
space:
mode:
Diffstat (limited to 'pkg/syserr/host_linux.go')
-rw-r--r--pkg/syserr/host_linux.go9
1 files changed, 5 insertions, 4 deletions
diff --git a/pkg/syserr/host_linux.go b/pkg/syserr/host_linux.go
index 77faa3670..c8c10f48b 100644
--- a/pkg/syserr/host_linux.go
+++ b/pkg/syserr/host_linux.go
@@ -18,7 +18,8 @@ package syserr
import (
"fmt"
- "syscall"
+
+ "golang.org/x/sys/unix"
)
const maxErrno = 134
@@ -30,15 +31,15 @@ type linuxHostTranslation struct {
var linuxHostTranslations [maxErrno]linuxHostTranslation
-// FromHost translates a syscall.Errno to a corresponding Error value.
-func FromHost(err syscall.Errno) *Error {
+// FromHost translates a unix.Errno to a corresponding Error value.
+func FromHost(err unix.Errno) *Error {
if int(err) >= len(linuxHostTranslations) || !linuxHostTranslations[err].ok {
panic(fmt.Sprintf("unknown host errno %q (%d)", err.Error(), err))
}
return linuxHostTranslations[err].err
}
-func addLinuxHostTranslation(host syscall.Errno, trans *Error) {
+func addLinuxHostTranslation(host unix.Errno, trans *Error) {
if linuxHostTranslations[host].ok {
panic(fmt.Sprintf("duplicate translation for host errno %q (%d)", host.Error(), host))
}